package Mouse::Meta::Attribute::Custom::Trait::Bar;
# This is automatically generated by author/import-moose-test.pl.
# DO NOT EDIT THIS FILE. ANY CHANGES WILL BE LOST!!!
use t::lib::MooseCompat;

sub register_implementation { 'My::Trait::Bar' }


package My::Trait::Bar;

use Mouse::Role;

1;
